@@ -28,13 +28,15 @@ class TestScaleDecoderClasses(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        RuntimeConfiguration().clear_type_registry()
-        RuntimeConfiguration().update_type_registry(load_type_registry_preset("default"))
+        cls.runtime_config = RuntimeConfigurationObject()
+        cls.runtime_config.clear_type_registry()
+        cls.runtime_config.update_type_registry(load_type_registry_preset("metadata_types"))
+        cls.runtime_config.update_type_registry(load_type_registry_preset("default"))
 
     def test_valid_decoding_classes(self):
-        for type_string in RuntimeConfiguration().type_registry['types'].keys():
+        for type_string in self.runtime_config.type_registry['types'].keys():
 
-            decoding_cls = RuntimeConfiguration().get_decoder_class(type_string)
+            decoding_cls = self.runtime_config.get_decoder_class(type_string)
 
             self.assertIsNotNone(decoding_cls, msg='"{}" didn\'t return decoding class'.format(type_string))
 
@@ -45,26 +47,28 @@ class TestScaleDecoderClasses(unittest.TestCase):
                     if type(sub_type_string) in [list, tuple]:
                         sub_type_string = sub_type_string[1]
 
-                    if type(sub_type_string) is dict:
-                        sub_type_mapping = [[k, v] for k, v in sub_type_string.items()]
-                        sub_decoding_cls = type(type_string, (Struct,), {'type_mapping': sub_type_mapping})
-                    else:
-                        sub_decoding_cls = RuntimeConfiguration().get_decoder_class(sub_type_string)
+                    if sub_type_string is not None:
 
-                    self.assertIsNotNone(sub_decoding_cls,
-                                         msg=f' Sub type "{sub_type_string}" didn\'t return decoding class')
-
-                    # Try to decode sub_type if present
-                    if sub_decoding_cls.sub_type:
-                        if sub_decoding_cls.sub_type[0] == '(':
-                            sub_sub_type_parts = [sub_decoding_cls.sub_type]
+                        if type(sub_type_string) is dict:
+                            sub_type_mapping = [[k, v] for k, v in sub_type_string.items()]
+                            sub_decoding_cls = type(type_string, (Struct,), {'type_mapping': sub_type_mapping})
                         else:
-                            sub_sub_type_parts = sub_decoding_cls.sub_type.split(',')
+                            sub_decoding_cls = self.runtime_config.get_decoder_class(sub_type_string)
 
-                        for sub_sub_type_part in sub_sub_type_parts:
-                            sub_sub_decoding_cls = RuntimeConfiguration().get_decoder_class(sub_sub_type_part.strip())
-                            self.assertIsNotNone(sub_sub_decoding_cls,
-                                                 msg=f' Sub type "{sub_sub_type_part}" didn\'t return decoding class')
+                        self.assertIsNotNone(sub_decoding_cls,
+                                             msg=f' Sub type "{sub_type_string}" didn\'t return decoding class')
+
+                        # Try to decode sub_type if present
+                        if sub_decoding_cls.sub_type:
+                            if sub_decoding_cls.sub_type[0] == '(':
+                                sub_sub_type_parts = [sub_decoding_cls.sub_type]
+                            else:
+                                sub_sub_type_parts = sub_decoding_cls.sub_type.split(',')
+
+                            for sub_sub_type_part in sub_sub_type_parts:
+                                sub_sub_decoding_cls = self.runtime_config.get_decoder_class(sub_sub_type_part.strip())
+                                self.assertIsNotNone(sub_sub_decoding_cls,
+                                                     msg=f' Sub type "{sub_sub_type_part}" didn\'t return decoding class')
 
 
 class TestMultipleRuntimeConfigurations(unittest.TestCase):
@@ -88,7 +92,7 @@ class TestMultipleRuntimeConfigurations(unittest.TestCase):
 
         runtime_config2 = RuntimeConfigurationObject()
 
-        self.assertIsNone(RuntimeConfiguration().get_decoder_class('MyNewType'))
+        self.assertIsNone(RuntimeConfigurationObject().get_decoder_class('MyNewType'))
         self.assertIsNotNone(runtime_config1.get_decoder_class('MyNewType'))
         self.assertIsNone(runtime_config2.get_decoder_class('MyNewType'))
 
